@@ -22,9 +22,9 @@ KNOWN ISSUES:
 """
 
 import importlib
-# import re
 import sys
 import six
+from typing import Dict, Union, Callable, Optional  # NOQA
 from django.apps import apps
 from django.core.management import BaseCommand, CommandError, sql as _sql
 from django.core.management.base import OutputWrapper
@@ -37,20 +37,20 @@ from django_extensions.management.utils import signalcommand
 ORDERING_FIELD = IntegerField('_order', null=True)
 
 
-def flatten(l, ltypes=(list, tuple)):
-    ltype = type(l)
-    l = list(l)
+def flatten(lst, ltypes=(list, tuple)):
+    ltype = type(lst)
+    lst = list(lst)
     i = 0
-    while i < len(l):
-        while isinstance(l[i], ltypes):
-            if not l[i]:
-                l.pop(i)
+    while i < len(lst):
+        while isinstance(lst[i], ltypes):
+            if not lst[i]:
+                lst.pop(i)
                 i -= 1
                 break
             else:
-                l[i:i + 1] = l[i]
+                lst[i:i + 1] = lst[i]
         i += 1
-    return ltype(l)
+    return ltype(lst)
 
 
 def all_local_fields(meta):
@@ -68,7 +68,7 @@ def all_local_fields(meta):
 
 
 class SQLDiff(object):
-    DATA_TYPES_REVERSE_OVERRIDE = {}
+    DATA_TYPES_REVERSE_OVERRIDE = {}  # type: Dict[int, Union[str, Callable]]
 
     IGNORE_MISSING_TABLES = [
         "django_migrations",
@@ -128,7 +128,7 @@ class SQLDiff(object):
 
     can_detect_notnull_differ = False
     can_detect_unsigned_differ = False
-    unsigned_suffix = None
+    unsigned_suffix = None  # type: Optional[str]
 
     def __init__(self, app_models, options):
         self.has_differences = None
@@ -190,6 +190,7 @@ class SQLDiff(object):
         self.differences[-1][-1].append((diff_type, args))
 
     def get_data_types_reverse_override(self):
+        # type: () -> Dict[int, Union[str, Callable]]
         return self.DATA_TYPES_REVERSE_OVERRIDE
 
     def get_django_tables(self, only_existing):
@@ -393,6 +394,8 @@ class SQLDiff(object):
                 else:
                     op = 'field-missing-in-db'
                 field_output.append(field.db_type(connection=connection))
+                if self.options.get('include_defaults') and field.has_default():
+                    field_output.append('DEFAULT %s' % field.get_prep_value(field.get_default()))
                 if not field.null:
                     field_output.append('NOT NULL')
                 self.add_difference(op, table_name, field_name, *field_output)
@@ -471,7 +474,7 @@ class SQLDiff(object):
             table_name = meta.db_table
             app_label = meta.app_label
 
-            if self.options.get('include_proxy_models', False) and meta.proxy:
+            if not self.options.get('include_proxy_models', False) and meta.proxy:
                 continue
 
             if cur_app_label != app_label:
@@ -1019,6 +1022,10 @@ to check/debug ur models compared to the real database tables and columns."""
             '--include-proxy-models', action='store_true', dest='include_proxy_models',
             default=False,
             help="Include proxy models in the graph")
+        parser.add_argument(
+            '--include-defaults', action='store_true', dest='include_defaults',
+            default=False,
+            help="Include default values in SQL output (beta feature)")
 
     def __init__(self, *args, **kwargs):
         super(Command, self).__init__(*args, **kwargs)
